pub enum ActionMessage {
Progress(f64),
Status(String),
Fail(String),
SetEnv {
name: String,
value: String,
},
UnsetEnv {
name: String,
},
RedactedEnv {
name: String,
value: String,
},
CancelMarkFailed {
fail_message: String,
},
}Expand description
A parsed openjd stdout message from a running action.
Variants
Progress(f64)
openjd_progress: <number>
Status(String)
openjd_status: <message>
Fail(String)
openjd_fail: <message>
SetEnv
openjd_env: <var>=<value>
UnsetEnv
openjd_unset_env: <var>
RedactedEnv
openjd_redacted_env: <var>=<value>
CancelMarkFailed
Request to cancel the action and mark it as failed (from malformed env commands)